@@ -1,9 +1,10 @@
-/* A Bison parser, made by GNU Bison 2.4.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2009, 2010 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.4.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -77,23 +78,15 @@
 /* Line 189 of yacc.c  */
 #line 1 "./mp-equation-parser.y"
 
-/*  Copyright (c) 2004-2008 Sami Pietila
- *  Copyright (c) 2008-2009 Robert Ancell
+/*
+ * Copyright (C) 2004-2008 Sami Pietila
+ * Copyright (C) 2008-2011 Robert Ancell
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
- *
- *  This program is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- *  General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- *  02111-1307, USA.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 2 of the License, or (at your option) any later
+ * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
+ * license.
  */
 
 #include <stdio.h>
@@ -244,7 +237,7 @@ static void do_conversion(yyscan_t yyscanner, const MPNumber *x, const char *x_u
 
 
 /* Line 189 of yacc.c  */
-#line 248 "mp-equation-parser.c"
+#line 241 "mp-equation-parser.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -341,7 +334,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 174 "./mp-equation-parser.y"
+#line 166 "./mp-equation-parser.y"
 
   MPNumber int_t;
   int integer;
@@ -350,7 +343,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 354 "mp-equation-parser.c"
+#line 347 "mp-equation-parser.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -375,7 +368,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 379 "mp-equation-parser.c"
+#line 372 "mp-equation-parser.c"
 
 #ifdef short
 # undef short
@@ -425,7 +418,7 @@ typedef short int yytype_int16;
 #define YYSIZE_MAXIMUM ((YYSIZE_T) -1)
 
 #ifndef YY_
-# if defined YYENABLE_NLS && YYENABLE_NLS
+# if YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
 #   define YY_(msgid) dgettext ("bison-runtime", msgid)
@@ -679,13 +672,13 @@ static const yytype_int8 yyrhs[] =
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
-static const yytype_uint16 yyrline[] =
+static const yytype_uint8 yyrline[] =
 {
-       0,   203,   203,   204,   205,   206,   207,   211,   212,   217,
-     218,   219,   220,   221,   222,   223,   224,   225,   226,   227,
-     228,   229,   230,   231,   232,   233,   234,   235,   236,   237,
-     238,   239,   240,   241,   242,   243,   244,   249,   250,   251,
-     252,   253,   254,   255,   256,   257,   261,   262,   263
+       0,   195,   195,   196,   197,   198,   199,   203,   204,   209,
+     210,   211,   212,   213,   214,   215,   216,   217,   218,   219,
+     220,   221,   222,   223,   224,   225,   226,   227,   228,   229,
+     230,   231,   232,   233,   234,   235,   236,   241,   242,   243,
+     244,   245,   246,   247,   248,   249,   253,   254,   255
 };
 #endif
 
@@ -930,18 +923,9 @@ static const yytype_uint8 yystos[] =
 
 /* Like YYERROR except do call yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
-   Once GCC version 2 has supplanted version 1, this can go.  However,
-   YYFAIL appears to be in use.  Nevertheless, it is formally deprecated
-   in Bison 2.4.2's NEWS entry, where a plan to phase it out is
-   discussed.  */
+   Once GCC version 2 has supplanted version 1, this can go.  */
 
 #define YYFAIL		goto yyerrlab
-#if defined YYFAIL
-  /* This is here to suppress warnings from the GCC cpp's
-     -Wunused-macros.  Normally we don't worry about that warning, but
-     some users do, and we want to make it easy for users to remove
-     YYFAIL uses, which will produce warnings from Bison 2.5.  */
-#endif
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
@@ -998,7 +982,7 @@ while (YYID (0))
    we won't break user code: when these are the locations we know.  */
 
 #ifndef YY_LOCATION_PRINT
-# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+# if YYLTYPE_IS_TRIVIAL
 #  define YY_LOCATION_PRINT(File, Loc)			\
      fprintf (File, "%d.%d-%d.%d",			\
 	      (Loc).first_line, (Loc).first_column,	\
@@ -1540,7 +1524,7 @@ YYLTYPE yylloc;
     YYLTYPE *yylsp;
 
     /* The locations where the error started and ended.  */
-    YYLTYPE yyerror_range[3];
+    YYLTYPE yyerror_range[2];
 
     YYSIZE_T yystacksize;
 
@@ -1587,7 +1571,7 @@ YYLTYPE yylloc;
   yyvsp = yyvs;
   yylsp = yyls;
 
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+#if YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
   yylloc.first_column = yylloc.last_column = 1;
@@ -1777,337 +1761,337 @@ yyreduce:
     {
         case 2:
 
-/* Line 1464 of yacc.c  */
-#line 203 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 195 "./mp-equation-parser.y"
     { set_result(yyscanner, &(yyvsp[(1) - (1)].int_t)); }
     break;
 
   case 3:
 
-/* Line 1464 of yacc.c  */
-#line 204 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 196 "./mp-equation-parser.y"
     { set_result(yyscanner, &(yyvsp[(1) - (2)].int_t)); }
     break;
 
   case 4:
 
-/* Line 1464 of yacc.c  */
-#line 205 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 197 "./mp-equation-parser.y"
     {set_variable(yyscanner, (yyvsp[(1) - (3)].name), &(yyvsp[(3) - (3)].int_t)); set_result(yyscanner, &(yyvsp[(3) - (3)].int_t)); }
     break;
 
   case 5:
 
-/* Line 1464 of yacc.c  */
-#line 206 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 198 "./mp-equation-parser.y"
     { MPNumber t; do_conversion(yyscanner, &(yyvsp[(1) - (4)].int_t), (yyvsp[(2) - (4)].name), (yyvsp[(4) - (4)].name), &t); set_result(yyscanner, &t); free((yyvsp[(2) - (4)].name)); free((yyvsp[(4) - (4)].name)); }
     break;
 
   case 6:
 
-/* Line 1464 of yacc.c  */
-#line 207 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 199 "./mp-equation-parser.y"
     { MPNumber x, t; mp_set_from_integer(1, &x); do_conversion(yyscanner, &x, (yyvsp[(1) - (3)].name), (yyvsp[(3) - (3)].name), &t); set_result(yyscanner, &t); free((yyvsp[(1) - (3)].name)); free((yyvsp[(3) - (3)].name)); }
     break;
 
   case 7:
 
-/* Line 1464 of yacc.c  */
-#line 211 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 203 "./mp-equation-parser.y"
     {(yyval.name) = (yyvsp[(1) - (1)].name);}
     break;
 
   case 8:
 
-/* Line 1464 of yacc.c  */
-#line 212 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 204 "./mp-equation-parser.y"
     {(yyval.name) = make_unit((yyvsp[(1) - (2)].name), (yyvsp[(2) - (2)].integer)); free((yyvsp[(1) - (2)].name));}
     break;
 
   case 9:
 
-/* Line 1464 of yacc.c  */
-#line 217 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 209 "./mp-equation-parser.y"
     {mp_set_from_mp(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 10:
 
-/* Line 1464 of yacc.c  */
-#line 218 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 210 "./mp-equation-parser.y"
     {mp_multiply(&(yyvsp[(1) - (4)].int_t), &(yyvsp[(3) - (4)].int_t), &(yyval.int_t));}
     break;
 
   case 11:
 
-/* Line 1464 of yacc.c  */
-#line 219 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 211 "./mp-equation-parser.y"
     {mp_floor(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 12:
 
-/* Line 1464 of yacc.c  */
-#line 220 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 212 "./mp-equation-parser.y"
     {mp_ceiling(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 13:
 
-/* Line 1464 of yacc.c  */
-#line 221 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 213 "./mp-equation-parser.y"
     {mp_round(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 14:
 
-/* Line 1464 of yacc.c  */
-#line 222 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 214 "./mp-equation-parser.y"
     {mp_fractional_part(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 15:
 
-/* Line 1464 of yacc.c  */
-#line 223 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 215 "./mp-equation-parser.y"
     {mp_abs(&(yyvsp[(2) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 16:
 
-/* Line 1464 of yacc.c  */
-#line 224 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 216 "./mp-equation-parser.y"
     {mp_xpowy(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 17:
 
-/* Line 1464 of yacc.c  */
-#line 225 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 217 "./mp-equation-parser.y"
     {mp_xpowy_integer(&(yyvsp[(1) - (2)].int_t), (yyvsp[(2) - (2)].integer), &(yyval.int_t));}
     break;
 
   case 18:
 
-/* Line 1464 of yacc.c  */
-#line 226 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 218 "./mp-equation-parser.y"
     {mp_xpowy_integer(&(yyvsp[(1) - (2)].int_t), (yyvsp[(2) - (2)].integer), &(yyval.int_t));}
     break;
 
   case 19:
 
-/* Line 1464 of yacc.c  */
-#line 227 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 219 "./mp-equation-parser.y"
     {mp_factorial(&(yyvsp[(1) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 20:
 
-/* Line 1464 of yacc.c  */
-#line 228 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 220 "./mp-equation-parser.y"
     {mp_set_from_mp(&(yyvsp[(1) - (1)].int_t), &(yyval.int_t));}
     break;
 
   case 21:
 
-/* Line 1464 of yacc.c  */
-#line 229 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 221 "./mp-equation-parser.y"
     {mp_multiply(&(yyvsp[(1) - (2)].int_t), &(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 22:
 
-/* Line 1464 of yacc.c  */
-#line 230 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 222 "./mp-equation-parser.y"
     {mp_invert_sign(&(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 23:
 
-/* Line 1464 of yacc.c  */
-#line 231 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 223 "./mp-equation-parser.y"
     {mp_set_from_mp(&(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 24:
 
-/* Line 1464 of yacc.c  */
-#line 232 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 224 "./mp-equation-parser.y"
     {mp_divide(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 25:
 
-/* Line 1464 of yacc.c  */
-#line 233 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 225 "./mp-equation-parser.y"
     {mp_modulus_divide(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 26:
 
-/* Line 1464 of yacc.c  */
-#line 234 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 226 "./mp-equation-parser.y"
     {mp_multiply(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 27:
 
-/* Line 1464 of yacc.c  */
-#line 235 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 227 "./mp-equation-parser.y"
     {mp_add_integer(&(yyvsp[(3) - (4)].int_t), 100, &(yyvsp[(3) - (4)].int_t)); mp_divide_integer(&(yyvsp[(3) - (4)].int_t), 100, &(yyvsp[(3) - (4)].int_t)); mp_multiply(&(yyvsp[(1) - (4)].int_t), &(yyvsp[(3) - (4)].int_t), &(yyval.int_t));}
     break;
 
   case 28:
 
-/* Line 1464 of yacc.c  */
-#line 236 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 228 "./mp-equation-parser.y"
     {mp_add_integer(&(yyvsp[(3) - (4)].int_t), -100, &(yyvsp[(3) - (4)].int_t)); mp_divide_integer(&(yyvsp[(3) - (4)].int_t), -100, &(yyvsp[(3) - (4)].int_t)); mp_multiply(&(yyvsp[(1) - (4)].int_t), &(yyvsp[(3) - (4)].int_t), &(yyval.int_t));}
     break;
 
   case 29:
 
-/* Line 1464 of yacc.c  */
-#line 237 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 229 "./mp-equation-parser.y"
     {mp_add(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 30:
 
-/* Line 1464 of yacc.c  */
-#line 238 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 230 "./mp-equation-parser.y"
     {mp_subtract(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 31:
 
-/* Line 1464 of yacc.c  */
-#line 239 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 231 "./mp-equation-parser.y"
     {mp_divide_integer(&(yyvsp[(1) - (2)].int_t), 100, &(yyval.int_t));}
     break;
 
   case 32:
 
-/* Line 1464 of yacc.c  */
-#line 240 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 232 "./mp-equation-parser.y"
     {do_not(yyscanner, &(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 33:
 
-/* Line 1464 of yacc.c  */
-#line 241 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 233 "./mp-equation-parser.y"
     {mp_and(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 34:
 
-/* Line 1464 of yacc.c  */
-#line 242 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 234 "./mp-equation-parser.y"
     {mp_or(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 35:
 
-/* Line 1464 of yacc.c  */
-#line 243 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 235 "./mp-equation-parser.y"
     {mp_xor(&(yyvsp[(1) - (3)].int_t), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t));}
     break;
 
   case 36:
 
-/* Line 1464 of yacc.c  */
-#line 244 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 236 "./mp-equation-parser.y"
     {mp_set_from_mp(&(yyvsp[(1) - (1)].int_t), &(yyval.int_t));}
     break;
 
   case 37:
 
-/* Line 1464 of yacc.c  */
-#line 249 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 241 "./mp-equation-parser.y"
     {mp_set_from_mp(&(yyvsp[(1) - (1)].int_t), &(yyval.int_t));}
     break;
 
   case 38:
 
-/* Line 1464 of yacc.c  */
-#line 250 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 242 "./mp-equation-parser.y"
     {if (!get_function(yyscanner, (yyvsp[(1) - (2)].name), &(yyvsp[(2) - (2)].int_t), &(yyval.int_t))) YYABORT; free((yyvsp[(1) - (2)].name));}
     break;
 
   case 39:
 
-/* Line 1464 of yacc.c  */
-#line 251 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 243 "./mp-equation-parser.y"
     {if (!get_function(yyscanner, (yyvsp[(1) - (3)].name), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t))) YYABORT; mp_xpowy_integer(&(yyval.int_t), (yyvsp[(2) - (3)].integer), &(yyval.int_t)); free((yyvsp[(1) - (3)].name));}
     break;
 
   case 40:
 
-/* Line 1464 of yacc.c  */
-#line 252 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 244 "./mp-equation-parser.y"
     {if (!get_inverse_function(yyscanner, (yyvsp[(1) - (3)].name), &(yyvsp[(3) - (3)].int_t), &(yyval.int_t))) YYABORT; mp_xpowy_integer(&(yyval.int_t), -(yyvsp[(2) - (3)].integer), &(yyval.int_t)); free((yyvsp[(1) - (3)].name));}
     break;
 
   case 41:
 
-/* Line 1464 of yacc.c  */
-#line 253 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 245 "./mp-equation-parser.y"
     {set_error(yyscanner, PARSER_ERR_UNKNOWN_FUNCTION, (yyvsp[(1) - (3)].name)); free((yyvsp[(1) - (3)].name)); YYABORT;}
     break;
 
   case 42:
 
-/* Line 1464 of yacc.c  */
-#line 254 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 246 "./mp-equation-parser.y"
     {mp_root(&(yyvsp[(3) - (3)].int_t), (yyvsp[(1) - (3)].integer), &(yyval.int_t));}
     break;
 
   case 43:
 
-/* Line 1464 of yacc.c  */
-#line 255 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 247 "./mp-equation-parser.y"
     {mp_sqrt(&(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
   case 44:
 
-/* Line 1464 of yacc.c  */
-#line 256 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 248 "./mp-equation-parser.y"
     {mp_root(&(yyvsp[(2) - (2)].int_t), 3, &(yyval.int_t));}
     break;
 
   case 45:
 
-/* Line 1464 of yacc.c  */
-#line 257 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 249 "./mp-equation-parser.y"
     {mp_root(&(yyvsp[(2) - (2)].int_t), 4, &(yyval.int_t));}
     break;
 
   case 46:
 
-/* Line 1464 of yacc.c  */
-#line 261 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 253 "./mp-equation-parser.y"
     {if (!get_variable(yyscanner, (yyvsp[(1) - (1)].name), 1, &(yyval.int_t))) YYABORT; free((yyvsp[(1) - (1)].name));}
     break;
 
   case 47:
 
-/* Line 1464 of yacc.c  */
-#line 262 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 254 "./mp-equation-parser.y"
     {if (!get_variable(yyscanner, (yyvsp[(1) - (2)].name), (yyvsp[(2) - (2)].integer), &(yyval.int_t))) YYABORT; free((yyvsp[(1) - (2)].name));}
     break;
 
   case 48:
 
-/* Line 1464 of yacc.c  */
-#line 263 "./mp-equation-parser.y"
+/* Line 1455 of yacc.c  */
+#line 255 "./mp-equation-parser.y"
     {mp_multiply(&(yyvsp[(1) - (2)].int_t), &(yyvsp[(2) - (2)].int_t), &(yyval.int_t));}
     break;
 
 
 
-/* Line 1464 of yacc.c  */
-#line 2111 "mp-equation-parser.c"
+/* Line 1455 of yacc.c  */
+#line 2095 "mp-equation-parser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2179,7 +2163,7 @@ yyerrlab:
 #endif
     }
 
-  yyerror_range[1] = yylloc;
+  yyerror_range[0] = yylloc;
 
   if (yyerrstatus == 3)
     {
@@ -2216,7 +2200,7 @@ yyerrorlab:
   if (/*CONSTCOND*/ 0)
      goto yyerrorlab;
 
-  yyerror_range[1] = yylsp[1-yylen];
+  yyerror_range[0] = yylsp[1-yylen];
   /* Do not reclaim the symbols of the rule which action triggered
      this YYERROR.  */
   YYPOPSTACK (yylen);
@@ -2250,7 +2234,7 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      yyerror_range[1] = *yylsp;
+      yyerror_range[0] = *yylsp;
       yydestruct ("Error: popping",
 		  yystos[yystate], yyvsp, yylsp, yyscanner);
       YYPOPSTACK (1);
@@ -2260,10 +2244,10 @@ yyerrlab1:
 
   *++yyvsp = yylval;
 
-  yyerror_range[2] = yylloc;
+  yyerror_range[1] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
      the lookahead.  YYLOC is available though.  */
-  YYLLOC_DEFAULT (yyloc, yyerror_range, 2);
+  YYLLOC_DEFAULT (yyloc, (yyerror_range - 1), 2);
   *++yylsp = yyloc;
 
   /* Shift the error token.  */
@@ -2325,7 +2309,7 @@ yyreturn:
 
 
 
-/* Line 1684 of yacc.c  */
-#line 266 "./mp-equation-parser.y"
+/* Line 1675 of yacc.c  */
+#line 258 "./mp-equation-parser.y"
 
 
